@@ -20,6 +20,8 @@ in_root do
   gsub_file 'Gemfile', /^.*\bgem 'rails.*$/, ''
   gsub_file "Gemfile", /.*web-console.*/, ''
   gsub_file "Gemfile", /.*debugger.*/, ''
+  gsub_file "Gemfile", /.*byebug.*/, "gem 'byebug', '~> 9.0.6'"
+  gsub_file "Gemfile", /.*puma.*/, ""
 
   if Rails::VERSION::STRING >= '5.0.0'
     append_to_file('Gemfile', "gem 'rails-controller-testing', :git => 'https://github.com/rails/rails-controller-testing'\n")
