@@ -1,7 +1,9 @@
 require 'generators/rspec'
+require "rspec/rails/feature_check"
 
 module Rspec
   module Generators
+    # @private
     class MailerGenerator < Base
       argument :actions, :type => :array, :default => [], :banner => "method method"
 
@@ -15,6 +17,11 @@ module Rspec
           template "fixture", File.join("spec/fixtures", @path)
         end
       end
+
+      def generate_preview_files
+        return unless RSpec::Rails::FeatureCheck.has_action_mailer_preview?
+        template "preview.rb", File.join("spec/mailers/previews", class_path, "#{file_name}_preview.rb")
+      end
     end
   end
 end
