@@ -1,9 +1,9 @@
-require 'spec_helper'
+require 'rails_helper'
 
 <% output_attributes = attributes.reject{|attribute| [:datetime, :timestamp, :time, :date].index(attribute.type) } -%>
-describe "<%= ns_table_name %>/show" do
+RSpec.describe "<%= ns_table_name %>/show", <%= type_metatag(:view) %> do
   before(:each) do
-    @<%= ns_file_name %> = assign(:<%= ns_file_name %>, stub_model(<%= class_name %><%= output_attributes.empty? ? '))' : ',' %>
+    @<%= ns_file_name %> = assign(:<%= ns_file_name %>, <%= class_name %>.create!(<%= '))' if output_attributes.empty? %>
 <% output_attributes.each_with_index do |attribute, attribute_index| -%>
       :<%= attribute.name %> => <%= value_for(attribute) %><%= attribute_index == output_attributes.length - 1 ? '' : ','%>
 <% end -%>
@@ -14,15 +14,8 @@ describe "<%= ns_table_name %>/show" do
 
   it "renders attributes in <p>" do
     render
-<% unless webrat? -%>
-    # Run the generator again with the --webrat flag if you want to use webrat matchers
-<% end -%>
 <% for attribute in output_attributes -%>
-<% if webrat? -%>
-    rendered.should contain(<%= value_for(attribute) %>.to_s)
-<% else -%>
-    rendered.should match(/<%= eval(value_for(attribute)) %>/)
-<% end -%>
+    expect(rendered).to match(/<%= raw_value_for(attribute) %>/)
 <% end -%>
   end
 end
