@@ -4,12 +4,14 @@ require 'rspec/rails/matchers'
 
 module RSpec
   module Rails
+    # @api public
+    # Common rails example functionality.
     module RailsExampleGroup
       extend ActiveSupport::Concern
       include RSpec::Rails::SetupAndTeardownAdapter
       include RSpec::Rails::MinitestLifecycleAdapter if ::Rails::VERSION::STRING >= '4'
       include RSpec::Rails::MinitestAssertionAdapter
-      include RSpec::Rails::Matchers
+      include RSpec::Rails::FixtureSupport
     end
   end
 end
