@@ -1,4 +1,6 @@
 require 'rspec/rails/view_assigns'
+require 'rspec/rails/view_spec_methods'
+require 'rspec/rails/view_path_builder'
 
 module RSpec
   module Rails
@@ -29,6 +31,16 @@ module RSpec
 
       # DSL exposed to view specs.
       module ExampleMethods
+        extend ActiveSupport::Concern
+
+        included do
+          include ::Rails.application.routes.url_helpers
+
+          if ::Rails.application.routes.respond_to?(:mounted_helpers)
+            include ::Rails.application.routes.mounted_helpers
+          end
+        end
+
         # @overload render
         # @overload render({:partial => path_to_file})
         # @overload render({:partial => path_to_file}, {... locals ...})
@@ -157,8 +169,20 @@ module RSpec
           end
 
           controller.controller_path = _controller_path
-          controller.request.path_parameters[:controller] = _controller_path
-          controller.request.path_parameters[:action]     = _inferred_action unless _inferred_action =~ /^_/
+
+          path_params_to_merge = {}
+          path_params_to_merge[:controller] = _controller_path
+          path_params_to_merge[:action] = _inferred_action unless _inferred_action =~ /^_/
+
+          path_params = controller.request.path_parameters
+
+          controller.request.path_parameters = path_params.reverse_merge(path_params_to_merge)
+          controller.request.path = ViewPathBuilder.new(::Rails.application.routes).path_for(controller.request.path_parameters)
+          ViewSpecMethods.add_to(::ActionView::TestCase::TestController)
+        end
+
+        after do
+          ViewSpecMethods.remove_from(::ActionView::TestCase::TestController)
         end
 
         let(:_default_file_to_render) do |example|
