@@ -67,7 +67,14 @@ module RSpec
           end
 
           def failure_message
-            "expected to enqueue #{base_message}"
+            "expected to enqueue #{base_message}".tap do |msg|
+              if @unmatching_jobs.any?
+                msg << "\nQueued jobs:"
+                @unmatching_jobs.each do |job|
+                  msg << "\n  #{base_job_message(job)}"
+                end
+              end
+            end
           end
 
           def failure_message_when_negated
@@ -89,8 +96,8 @@ module RSpec
         private
 
           def check(jobs)
-            @matching_jobs_count = jobs.count do |job|
-              if serialized_attributes.all? { |key, value| value == job[key] }
+            @matching_jobs, @unmatching_jobs = jobs.partition do |job|
+              if arguments_match?(job) && other_attributes_match?(job)
                 args = ::ActiveJob::Arguments.deserialize(job[:args])
                 @block.call(*args)
                 true
@@ -98,6 +105,7 @@ module RSpec
                 false
               end
             end
+            @matching_jobs_count = @matching_jobs.size
 
             case @expectation_type
             when :exactly then @expected_number == @matching_jobs_count
@@ -115,9 +123,32 @@ module RSpec
             end
           end
 
+          def base_job_message(job)
+            msg_parts = []
+            msg_parts << "with #{::ActiveJob::Arguments.deserialize(job[:args])}" if job[:args].any?
+            msg_parts << "on queue #{job[:queue]}" if job[:queue]
+            msg_parts << "at #{Time.at(job[:at])}" if job[:at]
+
+            "#{job[:job].name} job".tap do |msg|
+              msg << " #{msg_parts.join(', ')}" if msg_parts.any?
+            end
+          end
+
+          def arguments_match?(job)
+            if @args.any?
+              deserialized_args = ::ActiveJob::Arguments.deserialize(job[:args])
+              RSpec::Mocks::ArgumentListMatcher.new(*@args).args_match?(*deserialized_args)
+            else
+              true
+            end
+          end
+
+          def other_attributes_match?(job)
+            serialized_attributes.all? { |key, value| value == job[key] }
+          end
+
           def serialized_attributes
             {}.tap do |attributes|
-              attributes[:args]  = ::ActiveJob::Arguments.serialize(@args) if @args.any?
               attributes[:at]    = @at.to_f if @at
               attributes[:queue] = @queue if @queue
               attributes[:job]   = @job if @job
