@@ -1,19 +1,15 @@
-require 'spec_helper'
-
 # Generators are not automatically loaded by Rails
 require 'generators/rspec/model/model_generator'
+require 'support/generators'
 
-describe Rspec::Generators::ModelGenerator do
-  # Tell the generator where to put its output (what it thinks of as Rails.root)
-  destination File.expand_path("../../../../../tmp", __FILE__)
-
-  before { prepare_destination }
+RSpec.describe Rspec::Generators::ModelGenerator, :type => :generator do
+  setup_default_destination
 
   it 'runs both the model and fixture tasks' do
     gen = generator %w(posts)
-    gen.should_receive :create_model_spec
-    gen.should_receive :create_fixture_file
-    capture(:stdout) { gen.invoke_all }
+    expect(gen).to receive :create_model_spec
+    expect(gen).to receive :create_fixture_file
+    gen.invoke_all
   end
 
   describe 'the generated files' do
@@ -25,15 +21,15 @@ describe Rspec::Generators::ModelGenerator do
       describe 'the spec' do
         subject { file('spec/models/posts_spec.rb') }
 
-        it { should exist }
-        it { should contain(/require 'spec_helper'/) }
-        it { should contain(/describe Posts/) }
+        it { is_expected.to exist }
+        it { is_expected.to contain(/require 'rails_helper'/) }
+        it { is_expected.to contain(/^RSpec.describe Posts, #{type_metatag(:model)}/) }
       end
 
       describe 'the fixtures' do
         subject { file('spec/fixtures/posts.yml') }
 
-        it { should contain(Regexp.new('# Read about fixtures at http://api.rubyonrails.org/classes/ActiveRecord/Fixtures.html')) }
+        it { is_expected.to contain(Regexp.new('# Read about fixtures at http://api.rubyonrails.org/classes/ActiveRecord/FixtureSet.html')) }
       end
     end
 
@@ -45,7 +41,7 @@ describe Rspec::Generators::ModelGenerator do
       describe 'the fixtures' do
         subject { file('spec/fixtures/posts.yml') }
 
-        it { should_not exist }
+        it { is_expected.not_to exist }
       end
     end
   end
