@@ -1,20 +1,16 @@
-require 'spec_helper'
-
 # Generators are not automatically loaded by Rails
 require 'generators/rspec/view/view_generator'
+require 'support/generators'
 
-describe Rspec::Generators::ViewGenerator do
-  # Tell the generator where to put its output (what it thinks of as Rails.root)
-  destination File.expand_path("../../../../../tmp", __FILE__)
-
-  before { prepare_destination }
+RSpec.describe Rspec::Generators::ViewGenerator, :type => :generator do
+  setup_default_destination
 
   describe 'with default template engine' do
     it 'generates a spec for the supplied action' do
       run_generator %w(posts index)
       file('spec/views/posts/index.html.erb_spec.rb').tap do |f|
-        f.should contain(/require 'spec_helper'/)
-        f.should contain(/describe "posts\/index"/)
+        expect(f).to contain(/require 'rails_helper'/)
+        expect(f).to contain(/^RSpec.describe \"posts\/index\", #{type_metatag(:view)}/)
       end
     end
 
@@ -22,8 +18,8 @@ describe Rspec::Generators::ViewGenerator do
       it 'generates a spec for the supplied action' do
         run_generator %w(admin/posts index)
         file('spec/views/admin/posts/index.html.erb_spec.rb').tap do |f|
-          f.should contain(/require 'spec_helper'/)
-          f.should contain(/describe "admin\/posts\/index"/)
+          expect(f).to contain(/require 'rails_helper'/)
+          expect(f).to contain(/^RSpec.describe \"admin\/posts\/index\", #{type_metatag(:view)}/)
         end
       end
     end
@@ -33,8 +29,8 @@ describe Rspec::Generators::ViewGenerator do
     it 'generates a spec for the supplied action' do
       run_generator %w(posts index --template_engine haml)
       file('spec/views/posts/index.html.haml_spec.rb').tap do |f|
-        f.should contain(/require 'spec_helper'/)
-        f.should contain(/describe "posts\/index"/)
+        expect(f).to contain(/require 'rails_helper'/)
+        expect(f).to contain(/^RSpec.describe \"posts\/index\", #{type_metatag(:view)}/)
       end
     end
   end
