@@ -2,20 +2,14 @@ require "spec_helper"
 
 module RSpec::Rails
   describe FeatureExampleGroup do
-    it { should be_included_in_files_in('./spec/features/') }
-    it { should be_included_in_files_in('.\\spec\\features\\') }
-
-    it "adds :type => :feature to the metadata" do
-      group = RSpec::Core::ExampleGroup.describe do
-        include FeatureExampleGroup
-      end
-
-      expect(group.metadata[:type]).to eq(:feature)
-    end
+    it_behaves_like "an rspec-rails example group mixin", :feature,
+      './spec/features/', '.\\spec\\features\\'
 
     it "includes Rails route helpers" do
-      Rails.application.routes.draw do
-        get "/foo", :as => :foo, :to => "foo#bar"
+      with_isolated_stderr do
+        Rails.application.routes.draw do
+          get "/foo", :as => :foo, :to => "foo#bar"
+        end
       end
 
       group = RSpec::Core::ExampleGroup.describe do
