@@ -28,11 +28,17 @@ if RSpec::Rails::FeatureCheck.has_active_job?
 end
 
 RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_active_job? do
-  include RSpec::Rails::Matchers
+  around do |example|
+    original_logger = ActiveJob::Base.logger
+    ActiveJob::Base.logger = Logger.new(nil) # Silence messages "[ActiveJob] Enqueued ...".
+    example.run
+    ActiveJob::Base.logger = original_logger
+  end
 
   let(:heavy_lifting_job) do
     Class.new(ActiveJob::Base) do
       def perform; end
+      def self.name; "HeavyLiftingJob"; end
     end
   end
 
@@ -40,12 +46,14 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
     Class.new(ActiveJob::Base) do
       def perform(*)
       end
+      def self.name; "HelloJob"; end
     end
   end
 
   let(:logging_job) do
     Class.new(ActiveJob::Base) do
       def perform; end
+      def self.name; "LoggingJob"; end
     end
   end
 
@@ -202,13 +210,21 @@ RSpec.describe "ActiveJob matchers", :skip => !RSpec::Rails::FeatureCheck.has_ac
       }.to have_enqueued_job.with(global_id_object)
     end
 
+    it "passes with provided argument matchers" do
+      expect {
+        hello_job.perform_later(42, "David")
+      }.to have_enqueued_job.with(42, "David")
+    end
+
     it "generates failure message with all provided options" do
       date = Date.tomorrow.noon
-      message = "expected to enqueue exactly 2 jobs, with [42], on queue low, at #{date}, but enqueued 0"
+      message = "expected to enqueue exactly 2 jobs, with [42], on queue low, at #{date}, but enqueued 0" + \
+                "\nQueued jobs:" + \
+                "\n  HelloJob job with [1], on queue default"
 
       expect {
         expect {
-          hello_job.perform_later
+          hello_job.perform_later(1)
         }.to have_enqueued_job(hello_job).with(42).on_queue("low").at(date).exactly(2).times
       }.to raise_error(message)
     end
