@@ -6,18 +6,22 @@ describe "be_routable" do
 
   before { @routes = double("routes") }
 
+  it "provides a description" do
+    expect(be_routable.description).to eq("be routable")
+  end
+
   context "with should" do
     it "passes if routes recognize the path" do
-      routes.stub(:recognize_path) { {} }
+      allow(routes).to receive(:recognize_path) { {} }
       expect do
-        {:get => "/a/path"}.should be_routable
+        expect({:get => "/a/path"}).to be_routable
       end.to_not raise_error
     end
 
     it "fails if routes do not recognize the path" do
-      routes.stub(:recognize_path) { raise ActionController::RoutingError.new('ignore') }
+      allow(routes).to receive(:recognize_path) { raise ActionController::RoutingError.new('ignore') }
       expect do
-        {:get => "/a/path"}.should be_routable
+        expect({:get => "/a/path"}).to be_routable
       end.to raise_error(/expected \{:get=>"\/a\/path"\} to be routable/)
     end
   end
@@ -25,16 +29,16 @@ describe "be_routable" do
   context "with should_not" do
 
     it "passes if routes do not recognize the path" do
-      routes.stub(:recognize_path) { raise ActionController::RoutingError.new('ignore') }
+      allow(routes).to receive(:recognize_path) { raise ActionController::RoutingError.new('ignore') }
       expect do
-        {:get => "/a/path"}.should_not be_routable
+        expect({:get => "/a/path"}).not_to be_routable
       end.to_not raise_error
     end
 
     it "fails if routes recognize the path" do
-      routes.stub(:recognize_path) { {:controller => "foo"} }
+      allow(routes).to receive(:recognize_path) { {:controller => "foo"} }
       expect do
-        {:get => "/a/path"}.should_not be_routable
+        expect({:get => "/a/path"}).not_to be_routable
       end.to raise_error(/expected \{:get=>"\/a\/path"\} not to be routable, but it routes to \{:controller=>"foo"\}/)
     end
   end
