@@ -11,45 +11,54 @@ describe "route_to" do
   it "provides a description" do
     matcher = route_to("these" => "options")
     matcher.matches?(:get => "path")
-    matcher.description.should == "route {:get=>\"path\"} to {\"these\"=>\"options\"}"
+    expect(matcher.description).to eq("route {:get=>\"path\"} to {\"these\"=>\"options\"}")
   end
 
   it "delegates to assert_recognizes" do
-    self.should_receive(:assert_recognizes).with({ "these" => "options" }, { :method=> :get, :path=>"path" }, {})
-    {:get => "path"}.should route_to("these" => "options")
+    expect(self).to receive(:assert_recognizes).with({ "these" => "options" }, { :method=> :get, :path=>"path" }, {})
+    expect({:get => "path"}).to route_to("these" => "options")
   end
 
   context "with shortcut syntax" do
     it "routes with extra options" do
-      self.should_receive(:assert_recognizes).with({ :controller => "controller", :action => "action", :extra => "options"}, { :method=> :get, :path=>"path" }, {})
-      get("path").should route_to("controller#action", :extra => "options")
+      expect(self).to receive(:assert_recognizes).with({ :controller => "controller", :action => "action", :extra => "options"}, { :method=> :get, :path=>"path" }, {})
+      expect(get("path")).to route_to("controller#action", :extra => "options")
     end
 
     it "routes without extra options" do
-      self.should_receive(:assert_recognizes).with(
-        {:controller => "controller", :action => "action"}, 
+      expect(self).to receive(:assert_recognizes).with(
+        {:controller => "controller", :action => "action"},
         {:method=> :get, :path=>"path" },
         {}
       )
-      get("path").should route_to("controller#action")
+      expect(get("path")).to route_to("controller#action")
     end
 
     it "routes with one query parameter" do
-      self.should_receive(:assert_recognizes).with(
+      expect(self).to receive(:assert_recognizes).with(
         {:controller => "controller", :action => "action", :queryitem => "queryvalue"},
         {:method=> :get, :path=>"path" },
         {'queryitem' => 'queryvalue' }
       )
-      get("path?queryitem=queryvalue").should route_to("controller#action", :queryitem => 'queryvalue')
+      expect(get("path?queryitem=queryvalue")).to route_to("controller#action", :queryitem => 'queryvalue')
     end
 
     it "routes with multiple query parameters" do
-      self.should_receive(:assert_recognizes).with(
+      expect(self).to receive(:assert_recognizes).with(
         {:controller => "controller", :action => "action", :queryitem => "queryvalue", :qi2 => 'qv2'},
         {:method=> :get, :path=>"path"},
         {'queryitem' => 'queryvalue', 'qi2' => 'qv2'}
       )
-      get("path?queryitem=queryvalue&qi2=qv2").should route_to("controller#action", :queryitem => 'queryvalue', :qi2 => 'qv2')
+      expect(get("path?queryitem=queryvalue&qi2=qv2")).to route_to("controller#action", :queryitem => 'queryvalue', :qi2 => 'qv2')
+    end
+
+    it "routes with nested query parameters" do
+      expect(self).to receive(:assert_recognizes).with(
+        {:controller => "controller", :action => "action", 'queryitem' => {'qi2' => 'qv2'}},
+        {:method=> :get, :path=>"path"},
+        {'queryitem' => {'qi2' => 'qv2'} }
+      )
+      expect(get("path?queryitem[qi2]=qv2")).to route_to("controller#action", 'queryitem' => { 'qi2' => 'qv2' })
     end
 
   end
@@ -58,7 +67,7 @@ describe "route_to" do
     context "when assert_recognizes passes" do
       it "passes" do
         expect do
-          {:get => "path"}.should route_to("these" => "options")
+          expect({:get => "path"}).to route_to("these" => "options")
         end.to_not raise_exception
       end
     end
@@ -69,7 +78,7 @@ describe "route_to" do
           raise ActiveSupport::TestCase::Assertion.new("this message")
         end
         expect do
-          {:get => "path"}.should route_to("these" => "options")
+          expect({:get => "path"}).to route_to("these" => "options")
         end.to raise_error(RSpec::Expectations::ExpectationNotMetError, "this message")
       end
     end
@@ -80,7 +89,7 @@ describe "route_to" do
           raise ActionController::RoutingError.new("this message")
         end
         expect do
-          {:get => "path"}.should route_to("these" => "options")
+          expect({:get => "path"}).to route_to("these" => "options")
         end.to raise_error(RSpec::Expectations::ExpectationNotMetError, "this message")
       end
     end
@@ -91,7 +100,7 @@ describe "route_to" do
           raise "oops"
         end
         expect do
-          {:get => "path"}.should route_to("these" => "options")
+          expect({:get => "path"}).to route_to("these" => "options")
         end.to raise_exception("oops")
       end
     end
@@ -100,9 +109,9 @@ describe "route_to" do
   context "with should_not" do
     context "when assert_recognizes passes" do
       it "fails with custom message" do
-        expect do
-          {:get => "path"}.should_not route_to("these" => "options")
-        end.to raise_error(/expected {:get=>"path"} not to route to {"these"=>"options"}/)
+        expect{
+          expect({:get => "path"}).not_to route_to("these" => "options")
+        }.to raise_error(/expected \{:get=>"path"\} not to route to \{"these"=>"options"\}/)
       end
     end
 
@@ -112,7 +121,7 @@ describe "route_to" do
           raise ActiveSupport::TestCase::Assertion.new("this message")
         end
         expect do
-          {:get => "path"}.should_not route_to("these" => "options")
+          expect({:get => "path"}).not_to route_to("these" => "options")
         end.to_not raise_error
       end
     end
@@ -123,7 +132,7 @@ describe "route_to" do
           raise ActionController::RoutingError.new("this message")
         end
         expect do
-          {:get => "path"}.should_not route_to("these" => "options")
+          expect({:get => "path"}).not_to route_to("these" => "options")
         end.to_not raise_error
       end
     end
@@ -134,7 +143,7 @@ describe "route_to" do
           raise "oops"
         end
         expect do
-          {:get => "path"}.should_not route_to("these" => "options")
+          expect({:get => "path"}).not_to route_to("these" => "options")
         end.to raise_exception("oops")
       end
     end
@@ -145,7 +154,7 @@ describe "route_to" do
       raise ActiveSupport::TestCase::Assertion, "this message"
     end
     expect do
-      {"this" => "path"}.should route_to("these" => "options")
+      expect({"this" => "path"}).to route_to("these" => "options")
     end.to raise_error("this message")
   end
 end
