@@ -19,7 +19,7 @@ RSpec.describe "Verify required rspec dependencies" do
 
     Bundler.with_clean_env do
       expect(`bundle exec #{script} 2>&1`).
-        to match(/uninitialized constant RSpec::Support \(NameError\)/).
+        to match(/uninitialized constant RSpec::Support/).
         or match(/undefined method `require_rspec_core' for RSpec::Support:Module/)
 
       expect($?.exitstatus).to eq(1)
